@@ -20,8 +20,7 @@
 #'   block design is considered. If block is informed, then a resolvable
 #'   alpha-lattice design (Patterson and Williams, 1976) is employed.
 #'   \strong{All effects, except the error, are assumed to be fixed.}
-#' @param verbose Logical argument. If \code{verbose = FALSE} the code will run
-#'   silently.
+#' @param verbose \strong{Deprecated argument. It will be retired in the next release.}
 #' @return A list where each element is the result for one variable containing:
 #'
 #' 1. \strong{individual}: A tidy tbl_df with the results of the individual
@@ -72,29 +71,40 @@ anova_ind <- function(.data,
                       rep,
                       resp,
                       block = NULL,
-                      verbose = TRUE) {
+                      verbose = "deprecated") {
+  if(verbose != "deprecated"){
+    warning("`verbose` is deprecated. It will be defunct in the new release.", call. = FALSE)
+  }
   if(!missing(block)){
     factors  <- .data %>%
-      select(ENV = {{env}},
-             GEN = {{gen}},
-             REP = {{rep}},
-             BLOCK = {{block}}) %>%
+      select({{env}},
+             {{gen}},
+             {{rep}},
+             {{block}}) %>%
       mutate_all(as.factor)
   } else{
     factors  <- .data %>%
-      select(ENV = {{env}},
-             GEN = {{gen}},
-             REP = {{rep}}) %>%
+      select({{env}},
+             {{gen}},
+             {{rep}}) %>%
       mutate_all(as.factor)
   }
   vars <- .data %>% select({{resp}}, -names(factors))
-  has_text_in_num(vars)
   vars %<>% select_numeric_cols()
+  if(!missing(block)){
+    factors %<>% set_names("ENV", "GEN", "REP", "BLOCK")
+  } else{
+    factors %<>% set_names("ENV", "GEN", "REP")
+  }
   listres <- list()
   nvar <- ncol(vars)
   for (var in 1:nvar) {
     data <- factors %>%
       mutate(mean = vars[[var]])
+    if(has_na(data)){
+      data <- remove_rows_na(data)
+      has_text_in_num(data)
+    }
     grouped <- data %>% split(dplyr::pull(., ENV))
     if(missing(block)){
       formula <- as.formula(paste0("mean ~ GEN + REP"))
@@ -160,15 +170,6 @@ anova_ind <- function(.data,
     temp <- list(individual = as_tibble(rownames_to_column(individual, "ENV")),
                  MSRratio = max(individual$MSE) / min(individual$MSE))
       listres[[paste(names(vars[var]))]] <- temp
-      if (verbose == TRUE) {
-        cat("variable", paste(names(vars[var])),"\n")
-        cat("---------------------------------------------------------------------------\n")
-        cat("Within-environment ANOVA results\n")
-        cat("---------------------------------------------------------------------------\n")
-        print(as.data.frame(temp$individual), digits = 3, row.names = FALSE)
-        cat("---------------------------------------------------------------------------\n\n")
-      }
-
   }
   invisible(structure(listres, class = "anova_ind"))
 }
@@ -215,6 +216,8 @@ print.anova_ind <- function(x, export = FALSE, file.name = NULL, digits = 3, ...
     var <- x[[i]]
     cat("Variable", names(x)[i], "\n")
     cat("---------------------------------------------------------------------------\n")
+    cat("Within-environment ANOVA results\n")
+    cat("---------------------------------------------------------------------------\n")
     print(var[[1]])
     cat("---------------------------------------------------------------------------\n")
     cat("\n\n\n")
