@@ -69,26 +69,34 @@ anova_joint <- function(.data,
                         verbose = TRUE) {
   if(!missing(block)){
     factors  <- .data %>%
-      select(ENV = {{env}},
-             GEN = {{gen}},
-             REP = {{rep}},
-             BLOCK = {{block}}) %>%
+      select({{env}},
+             {{gen}},
+             {{rep}},
+             {{block}}) %>%
       mutate_all(as.factor)
   } else{
     factors  <- .data %>%
-      select(ENV = {{env}},
-             GEN = {{gen}},
-             REP = {{rep}}) %>%
+      select({{env}},
+             {{gen}},
+             {{rep}}) %>%
       mutate_all(as.factor)
   }
   vars <- .data %>% select({{resp}}, -names(factors))
-  has_text_in_num(vars)
   vars %<>% select_numeric_cols()
+  if(!missing(block)){
+    factors %<>% set_names("ENV", "GEN", "REP", "BLOCK")
+  } else{
+    factors %<>% set_names("ENV", "GEN", "REP")
+  }
   listres <- list()
   nvar <- ncol(vars)
   for (var in 1:nvar) {
     data <- factors %>%
       mutate(mean = vars[[var]])
+    if(has_na(data)){
+      data <- remove_rows_na(data)
+      has_text_in_num(data)
+    }
     msr <- data %>%
       split_factors(ENV, keep_factors = T)
     if(missing(block)){
