@@ -102,18 +102,22 @@ gafem <- function(.data,
                   verbose = TRUE) {
   # RCBD
   if (missing(block) == TRUE) {
-    factors  <- .data %>%
-      select(GEN = {{gen}},
-             REP = {{rep}}) %>%
+    factors  <-
+      .data %>%
+      select({{gen}}, {{rep}}) %>%
       mutate_all(as.factor)
     vars <- .data %>% select({{resp}}, -names(factors))
-    has_text_in_num(vars)
     vars %<>% select_numeric_cols()
+    factors %<>% set_names("GEN", "REP")
     listres <- list()
     nvar <- ncol(vars)
     for (var in 1:nvar) {
       data <- factors %>%
         mutate(mean = vars[[var]])
+      if(has_na(data)){
+        data <- remove_rows_na(data)
+        has_text_in_num(data)
+      }
       Ngen <- nlevels(data$GEN)
       Nbloc <- nlevels(data$REP)
       ovmean <- mean(data$mean)
@@ -182,19 +186,22 @@ gafem <- function(.data,
   }
   # ALPHA-LATTICE
   if (missing(block) == FALSE) {
-    factors  <- .data %>%
-      select(GEN = {{gen}},
-             REP = {{rep}},
-             BLOCK = {{block}}) %>%
+    factors  <-
+      .data %>%
+      select({{gen}}, {{rep}}, {{block}}) %>%
       mutate_all(as.factor)
     vars <- .data %>% select({{resp}}, -names(factors))
-    has_text_in_num(vars)
     vars %<>% select_numeric_cols()
+    factors %<>% set_names("GEN", "REP", "BLOCK")
     listres <- list()
     nvar <- ncol(vars)
     for (var in 1:nvar) {
       data <- factors %>%
         mutate(mean = vars[[var]])
+      if(has_na(data)){
+        data <- remove_rows_na(data)
+        has_text_in_num(data)
+      }
       Ngen <- nlevels(data$GEN)
       Nbloc <- nlevels(data$REP)
       ovmean <- mean(data$mean)
