@@ -1,9 +1,11 @@
 #' Get data from a model easily
 #'
-#' Easily get data from some objects generated in the \strong{metan} package
-#' such as the WAASB and WAASBY indexes  (Olivoto et al., 2019a, 2019b) BLUPs,
-#' variance components, details of AMMI models and AMMI-based stability
-#' statistics.
+#' * \code{get_model_data()} Easily get data from some objects generated in the
+#' \strong{metan} package such as the WAASB and WAASBY indexes  (Olivoto et al.,
+#' 2019a, 2019b) BLUPs, variance components, details of AMMI models and
+#' AMMI-based stability statistics.
+#' * \code{gmd()} Is a shortcut to \code{get_model_data}.
+#' @name get_model_data
 #'
 #' @param x An object created with the functions \code{\link{AMMI_indexes}},
 #'   \code{\link{anova_ind}}, \code{\link{anova_joint}},
@@ -240,7 +242,6 @@
 #' Zali, H., E. Farshadfar, S.H. Sabaghpour, and R. Karimizadeh. 2012.
 #' Evaluation of genotype vs environment interaction in chickpea using measures
 #' of stability from AMMI model. Ann. Biol. Res. 3:3126-3136.
-#' \href{http://eprints.icrisat.ac.in/id/eprint/7173}{http://eprints.icrisat.ac.in/id/eprint/7173}
 #'
 #' @seealso \code{\link{AMMI_indexes}}, \code{\link{anova_ind}},
 #'   \code{\link{anova_joint}}, \code{\link{ecovalence}},  \code{\link{Fox}},
@@ -839,7 +840,7 @@ get_model_data <- function(x,
         column_to_first(PC, DF)
     }
   }
-  if (any(class(x) %in% c("waas", "waas_means"))){
+  if (has_class(x, c("waas", "waas_means"))){
     if (is.null(what)){
       what <- "WAAS"
     }
@@ -873,3 +874,12 @@ get_model_data <- function(x,
   }
   return(bind)
 }
+
+#' @name get_model_data
+#' @export
+gmd <- function(x,
+                what = NULL,
+                type = "GEN",
+                verbose = TRUE){
+  get_model_data(x, what, type, verbose)
+}
