@@ -178,21 +178,25 @@ waas <- function(.data,
                  verbose = TRUE) {
     if(!missing(block)){
         factors  <- .data %>%
-            select(ENV = {{env}},
-                   GEN = {{gen}},
-                   REP = {{rep}},
-                   BLOCK = {{block}}) %>%
+            select({{env}},
+                   {{gen}},
+                   {{rep}},
+                   {{block}}) %>%
             mutate_all(as.factor)
     } else{
         factors  <- .data %>%
-            select(ENV = {{env}},
-                   GEN = {{gen}},
-                   REP = {{rep}}) %>%
+            select({{env}},
+                   {{gen}},
+                   {{rep}}) %>%
             mutate_all(as.factor)
     }
     vars <- .data %>% select({{resp}}, -names(factors))
-    has_text_in_num(vars)
     vars %<>% select_numeric_cols()
+    if(!missing(block)){
+        factors %<>% set_names("ENV", "GEN", "REP", "BLOCK")
+    } else{
+        factors %<>% set_names("ENV", "GEN", "REP")
+    }
     nvar <- ncol(vars)
     if (!is.null(naxis)) {
         if (length(naxis) != nvar) {
@@ -243,12 +247,16 @@ waas <- function(.data,
     for (var in 1:nvar) {
         data <- factors %>%
             mutate(Y = vars[[var]])
+        if(has_na(data)){
+            data <- remove_rows_na(data)
+            has_text_in_num(data)
+        }
         Nenv <- length(unique(data$ENV))
         Ngen <- length(unique(data$GEN))
         minimo <- min(Nenv, Ngen) - 1
         vin <- vin + 1
         if(ind_anova == TRUE){
-            individual <- data %>% anova_ind(ENV, GEN, REP, Y, verbose = FALSE)
+            individual <- data %>% anova_ind(ENV, GEN, REP, Y)
         } else{
             individual = NULL
         }
