@@ -38,6 +38,9 @@
 #'   \code{p = 3}, i.e., three IPCAs will be used to compute the index WAAS.
 #' @param verbose Logical argument. If \code{verbose = FALSE} the code is run
 #'   silently.
+#' @param ... Arguments passed to the function
+#'   \code{\link{impute_missing_val}()} for imputation of missing values in case
+#'   of unbalanced data.
 #' @references Olivoto, T., A.D.C. L{\'{u}}cio, J.A.G. da silva, V.S. Marchioro,
 #'   V.Q. de Souza, and E. Jost. 2019a. Mean performance and stability in
 #'   multi-environment trials I: Combining features of AMMI and BLUP techniques.
@@ -90,15 +93,23 @@ waas_means <- function(.data,
                        mresp = NULL,
                        wresp = NULL,
                        min_expl_var = 85,
-                       verbose = TRUE){
-  factors  <- .data %>%
-    select(ENV = {{env}},
-           GEN = {{gen}}) %>%
+                       verbose = TRUE,
+                       ...){
+  factors  <-
+    .data %>%
+    select({{env}}, {{gen}}) %>%
     mutate_all(as.factor)
-  vars <- .data %>% select({{resp}}, -names(factors))
-  has_text_in_num(vars)
-  vars %<>% select_numeric_cols()
+  vars <-
+    .data %>%
+    select({{resp}}, -names(factors)) %>%
+    select_numeric_cols()
+  factors %<>% set_names("ENV", "GEN")
   nvar <- ncol(vars)
+  if (verbose == TRUE) {
+    pb <- progress_bar$new(
+      format = "Evaluating the variable :what [:bar]:percent",
+      clear = FALSE, total = nvar, width = 90)
+  }
   if (is.null(mresp)) {
     mresp <- replicate(nvar, 100)
     minresp <- 100 - mresp
@@ -129,8 +140,20 @@ waas_means <- function(.data,
   vin <- 0
   for (var in 1:nvar) {
     data <- factors %>%
-      mutate(Y = vars[[var]]) %>%
-      means_by(ENV, GEN)
+      mutate(Y = vars[[var]])
+    if(has_na(data)){
+      data <- remove_rows_na(data)
+      has_text_in_num(data)
+    }
+    data <-
+      means_by(data, GEN, ENV) %>%
+      make_mat(GEN, ENV, Y)
+    if(has_na(data)){
+      data <- impute_missing_val(data, verbose = verbose, ...)$.data
+      warning("Data imputation used to fill the GxE matrix", call. = FALSE)
+    }
+    data %<>% make_long()
+
     vin <- vin + 1
     MGEN <-
       means_by(data, GEN) %>%
@@ -211,15 +234,10 @@ waas_means <- function(.data,
                            proportion = weights,
                            cum_proportion = cumsum(weights)),
                       class = "waas_means")
-    if (nvar > 1) {
-      listres[[paste(names(vars[var]))]] <- temp
-      if (verbose == TRUE) {
-        cat("Evaluating variable", paste(names(vars[var])),
-            round((var - 1)/(length(vars) - 1) * 100, 1), "%", "\n")
-      }
-    } else {
-      listres[[paste(names(vars[var]))]] <- temp
+    if (verbose == TRUE) {
+      pb$tick(tokens = list(what = names(vars[var])))
     }
+    listres[[paste(names(vars[var]))]] <- temp
   }
   return(structure(listres, class = "waas_means"))
 }
